netapp_ontap.models.aggregate_space_block_storage API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_space_block_storage`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateSpaceBlockStorageSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateSpaceBlockStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `available GET`

    Space available in bytes.

    Example: 10156560384

  `full_threshold_percent GET`

    The aggregate used percentage at which 'monitor.volume.full' EMS is generated.

  `inactive_user_data GET`

    The size that is physically used in the block storage and has a cold temperature, in bytes. This property is only supported if the aggregate is either attached to a cloud store or can be attached to a cloud store. This is an advanced property; there is an added cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either block_storage.inactive_user_data or **.

    Example: 304448

  `size GET`

    Total usable space in bytes, not including WAFL reserve and aggregate Snapshot copy reserve.

    Example: 10156769280

  `used GET`

    Space used or reserved in bytes. Includes volume guarantees and aggregate metadata.

    Example: 2088960